<?php

declare(strict_types=1);

namespace Drupal\data_pipelines\Plugin\DatasetSource;

use Drupal\data_pipelines\DatasetData;
use Drupal\data_pipelines\Entity\DatasetInterface;
use Drupal\data_pipelines\Source\DatasetSourceBase;

/**
 * A class for providing csv as a source.
 *
 * @DatasetSource(
 *   id="csv",
 *   label="CSV",
 *   deriver="Drupal\data_pipelines\Plugin\DatasetSource\SourceDeriver"
 * )
 */
class CsvSource extends DatasetSourceBase {

  /**
   * {@inheritDoc}
   */
  public function extractDataFromDataSet(DatasetInterface $dataset): \Generator {
    try {
      $resource = $this->getResource($dataset);
      $header = fgetcsv($resource);
      $header_length = count($header);
      while (($file_row = fgetcsv($resource)) !== FALSE) {
        // Make sure the row has exactly the same number of columns as the
        // header.
        $normalized_row = array_pad(array_slice($file_row, 0, $header_length), $header_length, NULL);
        yield new DatasetData(array_combine($header, $normalized_row));
      }
      fclose($resource);
    }
    catch (\Exception $e) {
      $this->loggerChannel->critical($e->getMessage());
      yield from [];
    }
  }

}
