<?php

declare(strict_types=1);

namespace Drupal\data_pipelines\Plugin\DatasetSource;

use Drupal\data_pipelines\DatasetData;
use Drupal\data_pipelines\Entity\DatasetInterface;
use Drupal\data_pipelines\Source\DatasetSourceBase;

/**
 * A class for providing json as a source.
 *
 * @DatasetSource(
 *   id="json",
 *   label="JSON",
 *   deriver="Drupal\data_pipelines\Plugin\DatasetSource\SourceDeriver"
 * )
 */
class JsonSource extends DatasetSourceBase {

  /**
   * {@inheritDoc}
   */
  public function extractDataFromDataSet(DatasetInterface $dataset): \Generator {
    try {
      $resource = $this->getResource($dataset);
      $json = json_decode(stream_get_contents($resource), TRUE);
      if (array_values($json) === $json) {
        foreach ($json as $record) {
          yield new DatasetData($record);
        }
      }
      else {
        yield new DatasetData($json);
      }
      fclose($resource);
    }
    catch (\Exception $e) {
      $this->loggerChannel->critical($e->getMessage());
      yield from [];
    }
  }

}
