<?php

declare(strict_types=1);

namespace Drupal\data_pipelines\Source\Resource;

use Drupal\Core\Entity\ContentEntityInterface;

/**
 * A base class for source resources.
 */
abstract class SourceResourceBase implements SourceResourceInterface {

  /**
   * Gets the field value from a dataset.
   *
   * @param \Drupal\Core\Entity\ContentEntityInterface $entity
   *   Entity.
   * @param string $field_name
   *   Field name.
   * @param string|null $main_property_name
   *   Main property name.
   *
   * @return mixed
   *   Field value.
   */
  protected function getFieldValue(ContentEntityInterface $entity, string $field_name, string $main_property_name = NULL) {
    /** @var \Drupal\Core\Field\BaseFieldDefinition $field_definition */
    $field_definition = $entity->{$field_name}->getFieldDefinition();
    $main_property_name = $main_property_name ?? $field_definition->getMainPropertyName();
    return $entity->{$field_name}->{$main_property_name};
  }

}
